/**
 * 公共模块
 */
import {get,post} from './http'

/**
 * 上传错误日志
 */
 export const apiReportingErrInfo=params=>{
    let obj={
        ...params,
        timestamp:new Date().toLocaleString(),
        agent:'研报PC端',
        page:window.location.href
    }
    return post('/public/wechat_warning',{content:JSON.stringify(obj)})
}


/**
 * 获取所有可以申请的品种权限列表
 */
export const apiGetPermissionList=()=>{
    return get('/public/get_apply_variety_list')
}

/**
 * 获取分享用的小程序码
 * @param CodeScene 页面所需参数
 * @param CodePage  小程序页面路径
 */
export const apiGetWechatQRCode=params=>{
    return post('/pc/getSunCode',params)
}

/**
 * web端微信登录
 */
export const apiWxLoginInWeb=params=>{
    return get('/pc/login',params)
}

/**
 * web 手机号/邮箱直接登录
 * @param LoginType  登录方式 1手机号 2邮箱
 * @param AreaNum 手机号区号
 * @param Mobile
 * @param Email 
 * @param SmsCode 验证码
 * @param IsFreeLogin 是否免登录 true是 
 */
export const apiLoginForPhone=params=>{
    return post('/pc/pcLogin',{...params,IsFreeLogin:true})
}

/**
 * PC获取手机验证码
 * @param mobile 手机号
 * @param area_num 手机号区号
 */
export const apiGetPCSMSCode=params=>{
    return get('/pc/get_sms_code',params)
}

/**
 * PC获取邮箱验证码
 * @param email 邮箱
 */
export const apiGetPCEmailCode=params=>{
    return get('/pc/get_email_code',params)
}

/**
 * 获取手机验证码
 * @param mobile 手机号
 * @param area_num 手机号区号
 */
 export const apiGetSMSCode=params=>{
    return get('/user/get_sms_code',params)
}

/**
 * 获取邮箱验证码
 * @param email 邮箱
 */
export const apiGetEmailCode=params=>{
    return get('/user/get_email_code',params)
}

/**
 * 手机号/邮箱绑定
 * @param area_num 手机号区号
 * @param bind_type 1手机号 2邮箱
 * @param email
 * @param mobile
 * @param verify_code
 */
export const apiUserLogin=params=>{
	return post('/user/login',params)
}

/**
 * 获取海报
 * @param code_page 分享海报小程序页面地址
 * @param code_scene 小程序页面参数
 * @param source 来源 activity_detail(活动详情) activity_list(活动列表)
 *                    special_column_list(专栏列表) special_column_detail(专栏详情)
 *                    report_list(报告列表) report_detail(报告详情)
 *                    chart_list(图库列表) chart_detail(图库详情)
 * @param version 
 * @param pars 生成海报需要的页面参数
 */
export const apiGetPoster=params=>{
    return post('/public/get_share_poster',{version:'3.0',...params})
}

/**
 * 获取消息
 * @param type 消息类型：0-全部，1-留言回复通知，2-精选留言通知
 * @param page_size
 * @param current_index
 */
export const apiGetNoticeList=params=>{
    return get('/message/list',params)
}

/**
 * 消息一件已读
 * @param type 消息类型：0-全部，1-留言回复通知，2-精选留言通知
 */
export const apiReadAllNotice=params=>{
    return post('/message/batch/read',params)
}

/**
 * 消息已读 某一条
 * @param msg_id 消息ID
 */
export const apiReadOneNotice=params=>{
    return post('/message/read',params)
}

/**
 * 删除某条消息
 * @param msg_id 消息ID
 */
 export const apiDelOneNotice=params=>{
    return post('/message/delete',params)
}

/**
 * 公告FICC品种权限数据
 */
export const apiFICCPermissionList=()=>{
    return get('/company/permission/tree',{})
}

/**
 * 获取标签树
 */
export const apiGetTagTree = params=>{
    return get('/public/get_variety_tag_tree',params)
}

/**
 * 获取用户已绑定权限
 */

export const apiUserBindPermission=params=>{
    return get('/company/permission/bind',params)
}

/**
 * 更新媒体播放记录时长
 * @param id 日志ID
 * @param stop_seconds 访问时长
 * @param source 来源：1-问答社区; 2-语音播报; 3-视频社区; 4-路演视频
 */
export const apiViewLogUpdate=params=>{
    return post('/public/view_log/update',params)
}

// 获取手机号区号列表
export const apiTelAraeNumList=()=>{
    return get('/public/tel_area_list',{})
}

/**
 * 获取基本配置
 */
export const apiBaseConfig=()=>{
    return get('/base/business_conf',{})
}