/**
 * 报告模块
 */
import {get,post} from './http'


/**
 * 研报详情
 * @param report_id 
 */
export const apiReportDetail=params=>{
    return get('/report/detail',params)
}

/**
 * 章节详情
 * @param report_chapter_id
 */
export const apiChapterDetail=params=>{
    return get('/report/chapter/detail',params)
}

/**
 * 研报首页顶部权限菜单
 */
export const apiReportIndexPageAuthList=()=>{
    return get('/company/getPermissionList',{})
}

/**
 * 研报首页报告列表
 * @param chart_permission_id
 */
export const apiReportIndexPageList=params=>{
    return get('/report/collect',params)
}

/**
 * 研报搜索
 * @param key_word
 */
export const apiReportSearch=params=>{
    return get('/report/search',params)
}

/**
 * 分类数据
 */
export const apiReportClassify=()=>{
    return get('/pc/classify',{})
}

/**
 * 研报列表
 * @param classify_id_first
 * @param key_word
 */
export const apiReportList=params=>{
    return get('/report/list',params)
}

/**
 * 二级分类列表
 * @param classify_id_first
 */
export const apiSubClassifyList=params=>{
    return get('/classify/simple/list',params)
}

/**
 * 专栏列表
 * @param classify_id_first
 */
export const apiSpecialColumnList=params=>{
    return get('/classify/list',params)
}

/**
 * 专栏详情
 * @param classify_id_second
 */
export const apiSpecialColumnDetail=params=>{
    return get('/classify/detail',params)
}

/**
 * 专栏详情中目录
 * @param classify_id_second
 * @param current_index
 * @param page_size
 */
export const apiSpecialColumnReportList=params=>{
    return get('/classify/detail/reports',params)
}

/**
 * 章节详情中指标数据
 * @param report_chapter_id
 */
export const apiChapterTickerValue=params=>{
    return get('/report/chapter/ticker',params)
}

/**
 * 研报首页上新公告
 */
export const apiReportIndexNewbanner=()=>{
    return get('/pc/banner',{})
}

/**
 * 专栏详情中客户评价
 */
export const apiSpecialColumnComment=params=>{
    return get('/pc/comment',params)
}

/**
 * 首页最新资讯
 */
export const apiLatestNews=params=>{
    return get('/pc/latest_news',params)
}

/**
 * 报告详情中更多推荐
 */
export const apiReportMoreRecmd=params=>{
    return get('/pc/recommend',params)
}

/**
 * 报告详情中(报告合集\专栏详情)
 */
export const apiReportDetailBanner=params=>{
    return get('/pc/detail_banner',params)
}

/**
 * 报告点赞
 * @param report_id  报告ID
 * @param report_chapter_id  报告章节ID(只有晨报和周报需要传报告章节ID)
 * @param old_report_id  老后台报告ID （research_report_id）
 * @param old_report_chapter_id  老后台报告章节ID（research_report_type_id）(只有晨报和周报需要传报告章节ID)
 * @param source_agent 来源平台：1:小程序、2:小程序(pc)、3:公众号、4:官网web(pc)
 */
export const apiReportLike=params=>{
    let source_agent=2
	if(window.__wxjs_environment === 'miniprogram'){
		source_agent=2
	}else{
		source_agent=4
	}
    return post('/like/set',{...params,source_agent:source_agent})
}

/**
 * 发布报告留言
 * @param report_id  报告ID
 * @param report_chapter_id  报告章节ID(只有晨报和周报需要传报告章节ID)
 * @param old_report_id  老后台报告ID （research_report_id）
 * @param old_report_chapter_id  老后台报告章节ID（research_report_type_id）(只有晨报和周报需要传报告章节ID)
 * @param source_agent 来源平台：1:小程序、2:小程序(pc)、3:公众号、4:官网web(pc)
 * @param content  留言内容
 * @param is_show_name  是否匿名 0-匿名，1-不匿名
 */
export const apiReportComment=params=>{
    let source_agent=2
	if(window.__wxjs_environment === 'miniprogram'){
		source_agent=2
	}else{
		source_agent=4
	}
    return post('/comment/set',{...params,source_agent:source_agent})
}

/**
 * 获取报告中我的留言
 * @param report_id  报告ID
 * @param report_chapter_id  报告章节ID(只有晨报和周报需要传报告章节ID)
 * @param old_report_id  老后台报告ID （research_report_id）
 * @param old_report_chapter_id  老后台报告章节ID（research_report_type_id）(只有晨报和周报需要传报告章节ID)
 */
export const apiReportMyCommnet=params=>{
    return get('/comment/my',params)
}

/**
 * 获取报告中的精选留言
 * @param report_id  报告ID
 * @param report_chapter_id  报告章节ID(只有晨报和周报需要传报告章节ID)
 * @param old_report_id  老后台报告ID （research_report_id）
 * @param old_report_chapter_id  老后台报告章节ID（research_report_type_id）(只有晨报和周报需要传报告章节ID)
 * @param current_index
 * @param page_size
 */
export const apiReportHotCommentList=params=>{
    return get('/comment/hot',params)
}

/**
 * 删除报告中我的留言
 * @param comment_id
 */
export const apiDelMyComment=params=>{
    return post('/comment/del',params)
}

/**
 * 报告详情分享图片
 * @param source （目前写死的）rddp_share_img
 * @param pars json字符串类型参数{title:图片上的富文本,time_format:时间（没啥用）,background_img:背景图}
 */
export const apiRddpShareImg=params=>{
    return post('/report/detail/rddp_share_img',{source:'rddp_share_img',...params})
}

/**
 * 报告对应的ppt图片
 * @param report_id 报告id
 * @param report_chapter_id 报告章节id
 */
export const apiReportPPtImgs=params=>{
    return get('/report/ppt_img',params)
}

/**
 * 品种类型报告中品种筛选项
 * @param classify_id 分类id
 */
export const apiGoodsPermissionList=params=>{
    return get('/company/permission/commodities',params)
}

/**
 * 按品种查询报告列表
 * @param chart_permission_id 品种id
 * @param classify_id 分类id
 * @param current_index
 * @param page_size
 */
export const apiReportListForVariety=params=>{
    return get('/report/variety/list',params)
}

/**
 * 获取列表类型报告中的子目录数据
 * @param classify_id
 */
export const apiReportClassifyMenuList=params=>{
    return get('/classify/menu/list',params)
}

/**
 * 设置周报音频播放的播放清单
 * @param type_id 章节id
 * @param is_close 是否关闭:1,关闭,0:不关闭
 */
export const apiReportChapterAudioSet=params=>{
    return post('/report/report_chapter/set',params)
}

/**
 * 获取PDF详情
 * @param pdf_id 
 * @returns 
 */
 export const apiGetPDFDetail = params=>{
    return get('/report/pdf/detail',params)
}


/**
 * banner埋点
 * @param  "banner_url": "wwwwwwww",
 * @param   "first_source": 1, //一级来源 1小程序移动 2小程序pc 3研报官网
 * @param   "second_source": 1 //二级来源 1首页 2研报详情页
 * @returns 
 */
export const apiPublicBannerMark = params=>{
    return post('/public/banner/mark',params)
}



/**
 * banner图列表
 * @param  "banner_url": "wwwwwwww",
 * @param   "first_source": 1, //一级来源 1小程序移动 2小程序pc 3研报官网
 * @param   "second_source": 1 //二级来源 1首页 2研报详情页
 * @returns 
 */
export const apiPublicBannerList = params=>{
    return get('/public/banner/list',params)
}

/**
 * banner历史图列表
 * @returns 
 */
export const bannerHistoryList = params=>{
    return get('/public/banner_history/list',params)
}

/**
 * banner图获取报名二维码
 * @returns 
 */
export const bannerGetQrcode = params=>{
    return get('/public/banner/get_qrcode',params)
}