/**
 * 用户模块
 */
import {get,post} from './http'

/**
 * 获取个人信息
 */
export const apiUserInfo=()=>{
	return get('/user/info',{})
}

/**
 * 用户权限申请
 * @param business_card_url 名片地址
 * @param company_name 公司名
 * @param permission 选择的权限
 * @param real_name 姓名
 * @param source 来源：我的1、活动2、图库3、研报4、问答社区5、价格驱动6、沙盘推演7、语音播报8、视频社区9、线上路演10、事件日历11
 * @param source_agent 来源平台：1:小程序、2:小程序(pc)、3:公众号、4:官网web(pc)
 * @param from_page 来源页面: '活动列表'、'活动详情'等
 */
export const apiApplyPermission=params=>{
	let source_agent=2
	if(window.__wxjs_environment === 'miniprogram'){
		source_agent=2
	}else{
		source_agent=4
	}
	return post('/user/apply',{...params,source_agent:source_agent})
}

/**
 * 获取用户最近一条申请单信息
 */
export const apiLastApplyRecord=(params)=>{
	return get('/user/get_last_apply_record',params)
}

/**
 * 修改昵称和头像
 * @param nick_name
 * @param head_img_url
 */
export const apiSetUserInfo=params=>{
	return post('/user/set',params)
}

/**
 * 收藏
 * @param collection_type 收藏类型：1-研报; 2-视频社区; 3-微路演视频
 * @param primary_id //收藏类型主ID(如报告id,视频id)
 * @param extend_id //扩展ID-如研报章节ID
 * @param source_agent //操作来源：1-小程序 2-小程序 PC 3-弘则研究公众号 4-Web PC
 */
export const apiSetCollect=params=>{
	let source_agent=2
	if(window.__wxjs_environment === 'miniprogram'){
		source_agent=2
	}else{
		source_agent=4
	}
	return post('/collection/collect',{source_agent:source_agent,...params})
}

/**
 * 取消收藏
 * @param collection_id 收藏ID
 */
export const apiCancelCollect=params=>{
	return post('/collection/cancel',params)
}

/**
 * 我的收藏列表
 * @param curr_page
 * @param page_size
 * @param keywords
 * @param from_type 来源类型：0-全部; 1-研报; 2-线上路演; 3-视频社区
 */
export const apiMyCollectList=params=>{
	return get('/collection/list',params)
}